# Break dependency loops in a bootstrap situation
%bcond_with bootstrap

# Disable Maven reporting in bootstrap mode
%if %{without bootstrap}
%bcond_without maven_reporting
%else
%bcond_with maven_reporting
%endif

Name:           javacc-maven-plugin
Version:        3.1.0
Release:        %mkrel 3
Group:          Development/Java
Summary:        JavaCC Maven Plugin
License:        ASL 2.0
URL:            http://mojo.codehaus.org/javacc-maven-plugin/ 
BuildArch:      noarch
#ExclusiveArch:  %{java_arches} noarch

Source0:        https://github.com/mojohaus/javacc-maven-plugin/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.java.dev.javacc:javacc)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.codehaus.mojo:mojo-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.codehaus.plexus:plexus-xml)
%endif

%if %{with maven_reporting}
BuildRequires:  mvn(org.apache.maven.doxia:doxia-sink-api)
BuildRequires:  mvn(org.apache.maven.doxia:doxia-site-renderer)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-api)
BuildRequires:  mvn(org.apache.maven.reporting:maven-reporting-impl)
%endif

%description
Maven Plugin for processing JavaCC grammar files.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for %{name}.

%prep
%autosetup
cp -p %{SOURCE1} .

# Do not use jtb, which is unmaintained.  It is accessed only via reflection to
# avoid depending on Java 1.5 for compilation.
%pom_remove_dep edu.ucla.cs.compilers:jtb

# Disable integration tests
%pom_remove_plugin org.apache.maven.plugins:maven-invoker-plugin
rm -fr src/it

# Disable building the web site
rm -fr src/site

# In bootstrap mode, disable documentation and reporting
%if %{without maven_reporting}
%pom_remove_dep org.apache.maven.doxia:
%pom_remove_dep org.apache.maven.reporting:
rm src/main/java/org/codehaus/mojo/javacc/JJDocMojo.java
%endif

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%license LICENSE-2.0.txt src/main/resources/NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE-2.0.txt src/main/resources/NOTICE




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.1.0-3.mga10
+ Revision: 2223753
- Mageia 10 Mass Rebuild

* Tue May 21 2024 ns80 <ns80> 3.1.0-2.mga10
+ Revision: 2065488
- rebuild without bootstrap

* Tue May 21 2024 ns80 <ns80> 3.1.0-1.mga10
+ Revision: 2065474
- bootstrap build
- new version 3.1.0 for java 21

* Sat Mar 26 2022 umeabot <umeabot> 2.6-26.mga9
+ Revision: 1827289
- Mageia 9 Mass Rebuild

* Tue Feb 11 2020 umeabot <umeabot> 2.6-25.mga8
+ Revision: 1490571
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 2.6-24.mga7
+ Revision: 1262215
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 2.6-23.mga6
+ Revision: 1102612
- Add missing BuildRequires to fix FTBFS

* Wed Mar 02 2016 neoclust <neoclust> 2.6-22.mga6
+ Revision: 981854
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.6-21.mga6
+ Revision: 976458
- First rebuild of the java stack
- sync package javacc-maven-plugin with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 2.6-16.mga5
+ Revision: 805677
- Clean rebuild
- Sync with Fedora 21
- Restore
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 2.6-14.mga5
+ Revision: 747809
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 luigiwalser <luigiwalser> 2.6-12.mga4
+ Revision: 506418
- BR maven-local for mvn-rpmbuild
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.6-10.mga3
+ Revision: 354828
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 2.6-9.mga3
+ Revision: 325656
- Build with Maven 3

* Thu Apr 28 2011 dmorgan <dmorgan> 2.6-8.mga1
+ Revision: 92531
- Rebuild after bootstrapping
- imported package javacc-maven-plugin


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 6 2010 Orion Poplawski <orion@cora.nwra.com> 2.6-6
- Require mojo-parent.

* Thu Sep 16 2010 Alexander Kurtakov <akurtako@redhat.com> 2.6-5
- BR mojo-parent.

* Wed Mar 24 2010 Alexander Kurtakov <akurtako@redhat.com> 2.6-4
- Fix BRs.

* Wed Mar 24 2010 Alexander Kurtakov <akurtako@redhat.com> 2.6-3
- Fix plugin metadata build.

* Wed Mar 17 2010 Alexander Kurtakov <akurtako@redhat.com> 2.6-2
- Fix Requires.

* Mon Mar 15 2010 Alexander Kurtakov <akurtako@redhat.com> 2.6-1
- Initial package.
